pub enum ParseErrorKind {
RecordSeparatorInContinuation,
UnfinishedLine,
UnfinishedField,
UnfinishedRecord,
InvalidFieldName,
}Expand description
Parsing error kind.
Equivalent to openrj ORJ_PARSE_ERROR constants.
Variants
RecordSeparatorInContinuation
A record separator was encountered during a content line continuation.
UnfinishedLine
The last line in the database was not terminated by a line-feed.
UnfinishedField
The last field in the database file was not well-formed.
UnfinishedRecord
The last record was not terminated by a record separator.
InvalidFieldName
The field name was not valid.
Implementations